@@ -1,5 +1,6 @@
 from functools import partial
 
+from confluent_kafka_helpers.exceptions import KafkaDeliveryError, KafkaError
 from confluent_kafka_helpers.metrics.callbacks import (
     StatsCallbackMetrics, error_cb_metrics, on_delivery_cb_metrics
 )
@@ -17,6 +18,7 @@ def default_error_cb(error, custom_cb=None, send_metrics=error_cb_metrics):
     send_metrics(error)
     if custom_cb:
         custom_cb(error)
+    raise KafkaError(str(error))
 
 
 def default_on_delivery_cb(
@@ -25,6 +27,8 @@ def default_on_delivery_cb(
     send_metrics(error, message)
     if custom_cb:
         custom_cb(error, message)
+    if error:
+        raise KafkaDeliveryError(str(error), message)
 
 
 def default_stats_cb(stats, custom_cb=None, send_metrics=StatsCallbackMetrics):
